package com.xhkjedu.slive.service.xz;

import com.xhkjedu.slive.mapper.xz.XzMapper;
import com.xhkjedu.slive.model.xz.LXz;
import com.xhkjedu.utils.N_Utils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * @Description 行政直播概要
 * @Author WN
 * Date 2022/3/30 13:42
 **/
@Service
public class XzService {
    @Resource
    private XzMapper xzMapper;

    /**
     * @Description 行政直播列表
     * @Param [schoolid]
     * @Return java.util.List<java.util.Map>
     * @Author wn
     * @Date 2022/3/30 14:03
     **/
    public List<Map> listXzs(Integer schoolid, String xzname) {
        return xzMapper.listXzs(schoolid, xzname);
    }

    /**
     * @Description 保存行政直播
     * @Param [xz]
     * @Return void
     * @Author wn
     * @Date 2022/3/30 14:07
     **/
    public Integer saveXz(LXz xz) {
        xz.setCreatetime(N_Utils.getSecondTimestamp());
        xz.setDeleted(1);
        xzMapper.insertUseGeneratedKeys(xz);
        return xz.getId();
    }

    /**
     * @Description 修改行政直播
     * @Param [xz]
     * @Return void
     * @Author wn
     * @Date 2022/3/30 14:16
     **/
    public void updateXz(LXz xz) {
        xzMapper.updateByPrimaryKeySelective(xz);
    }

    //获取行政直播课下进行中或者已结束的直播课数量
    public Integer getXzSectionKsNum(Integer xzid) {
        Integer num = xzMapper.getXzSectionKsNum(xzid);
        if (num == null) {
            num = 0;
        }
        return num;
    }

    /**
     * @Description 删除行政直播
     * @Param [xzid]
     * @Return void
     * @Author wn
     * @Date 2022/3/30 15:24
     **/
    @Transactional
    public void deleteXz(Integer xzid) {
        //如果行政直播下所有的课都未开始，则可以直接删除，
        //如果有直播课已经开始则进行逻辑删除，并删除所有未开始上的直播课
        Integer sectionnum = xzMapper.getXzSectionKsNum(xzid);
        if (sectionnum != null && sectionnum > 0) {
            //说明直播下有开始或结束的课节，只能删除未开始的直播和直播班级信息
            xzMapper.deleteCourseClassKjByXzid(xzid);
            //修改行政直播的状态未已删除
            xzMapper.updateXzDeleted(10, xzid);
        } else {
            //说明该行政直播课程可以直接删除
            xzMapper.deleteCourseClassByXzid(xzid);
            xzMapper.deleteXzAndKjByXzid(xzid);
        }
    }
}
